package com.jay.monitor.data.server.report.alert.rule;

import com.jay.monitor.data.core.enums.MsgTypeEnums;
import com.jay.monitor.data.core.model.serializable.base.BaseDTO;
import com.jay.monitor.data.core.model.serializable.base.RequestDataData;
import com.jay.monitor.data.server.config.props.AlertProperties;
import com.jay.monitor.data.server.models.config.AlertConfigModel;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.InitializingBean;
import org.springframework.beans.factory.annotation.Autowired;

/**
 * @Module 告警规则
 * @Description 请求时长告警规则
 * @Author liukaixiong
 * @Date 2021/1/14 10:49
 */
public class RequestTimeAlertRule implements AlertRule, InitializingBean {

    private Logger logger = LoggerFactory.getLogger(getClass());

    @Autowired
    private AlertProperties alertProperties;

    private volatile boolean isEnableRule = false;

    @Override
    public String name() {
        return "请求耗时问题";
    }

    @Override
    public boolean isTrigger(BaseDTO baseDTO) {
        if (baseDTO instanceof RequestDataData) {
            MsgTypeEnums type = baseDTO.getType();
            RequestDataData requestData = (RequestDataData) baseDTO;
            Long requestTime = requestData.getRequestTime();
            if (requestTime != null) {
                AlertConfigModel alertConfigModel = alertProperties.getAlertConfigMap().get(type);

                if (alertConfigModel != null) {
                    Integer maxTime = alertConfigModel.getMaxTime();
                    if (requestTime >= maxTime) {
                        return true;
                    }
                }
            } else {
                logger.debug("not fond request time !");
            }
        }
        return false;
    }

    @Override
    public void afterPropertiesSet() throws Exception {
        this.isEnableRule = alertProperties.isEnable();

    }
}
